@@ -71,6 +71,8 @@ const static struct config_item config_items[] = {
     { "auto_reorder",       CONFIG_BOOL, OFFSET(auto_reorder)             },
     { "use_simplified_chinese", CONFIG_BOOL, OFFSET(use_simplified_chinese) },
     { "hanja_mode",         CONFIG_BOOL, OFFSET(hanja_mode)               },
+    { "ignore_app_fontset", CONFIG_BOOL, OFFSET(ignore_app_fontset)       },
+    { "use_system_keymap",  CONFIG_BOOL, OFFSET(use_system_keymap)        },
     { NULL,                 0,           0                                }
 };
 
@@ -190,7 +192,7 @@ nabi_config_new()
     config->palette_height = 24;
     config->use_tray_icon = TRUE;
     config->xim_name = g_string_new(PACKAGE);
-    config->theme = g_string_new("Jini");
+    config->theme = g_string_new(DEFAULT_THEME);
 
     config->hangul_keyboard = g_string_new(DEFAULT_KEYBOARD);
     config->latin_keyboard = g_string_new("none");
@@ -215,8 +217,9 @@ nabi_config_new()
     config->commit_by_word = FALSE;
     config->auto_reorder = TRUE;
     config->hanja_mode = FALSE;
-
     config->use_simplified_chinese = FALSE;
+    config->ignore_app_fontset = FALSE;
+    config->use_system_keymap = FALSE;
 
     return config;
 }
