@@ -51,6 +51,8 @@ struct _NabiConfig {
     gboolean        auto_reorder;
     gboolean        use_simplified_chinese;
     gboolean        hanja_mode;
+    gboolean        ignore_app_fontset;
+    gboolean        use_system_keymap;
 
     /* candidate options */
     GString*        candidate_font;
