@@ -126,6 +126,7 @@ struct _NabiIC {
     /* hanja or symbol select window */
     NabiCandidate*	candidate;
 
+    gboolean            composing_started;
     UString*            client_text;
     gboolean            wait_for_client_text; /* whether this ic requested
 					       * client text */
@@ -157,6 +158,8 @@ CARD16  nabi_ic_get_id(NabiIC* ic);
 void    nabi_ic_set_focus(NabiIC *ic);
 
 void    nabi_ic_set_mode(NabiIC *ic, NabiInputMode mode);
+void    nabi_ic_start_composing(NabiIC *ic);
+void    nabi_ic_end_composing(NabiIC *ic);
 
 void    nabi_ic_preedit_start(NabiIC *ic);
 void    nabi_ic_preedit_done(NabiIC *ic);
@@ -168,7 +171,6 @@ void    nabi_ic_status_done(NabiIC *ic);
 void    nabi_ic_status_update(NabiIC *ic);
 
 Bool    nabi_ic_commit(NabiIC *ic);
-Bool    nabi_ic_commit_keyval(NabiIC *ic, wchar_t ch, KeySym keyval);
 
 Bool    nabi_ic_process_keyevent(NabiIC* ic, KeySym keysym, unsigned int state);
 void    nabi_ic_flush(NabiIC *ic);
