@@ -1,5 +1,5 @@
 /* Nabi - X Input Method server for hangul
- * Copyright (C) 2003,2004 Choe Hwanjin
+ * Copyright (C) 2003-2008 Choe Hwanjin
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -19,9 +19,7 @@
 #ifndef _NABI_SESSION_H
 #define _NABI_SESSION_H
 
-#ifdef HAVE_LIBSM
 void nabi_session_open(char *previos_id);
 void nabi_session_close(void);
-#endif
 
 #endif /* _NABI_SESSION_H */
